@@ -1,5 +1,5 @@
 /*
- *      Copyright (C) 2004, 2006 Free Software Foundation, Inc.
+ *      Copyright (C) 2004, 2006, 2008 Free Software Foundation, Inc.
  *      Copyright (C) 2002 Fabio Fiorina
  *
  * This file is part of LIBTASN1.
@@ -23,9 +23,21 @@
 #ifndef INT_H
 #define INT_H
 
-#include <libtasn1.h>
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
 
-#include <defines.h>
+#include <string.h>
+#include <stdlib.h>
+#include <stdio.h>
+#include <ctype.h>
+#include <stdint.h>
+
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
+
+#include <libtasn1.h>
 
 /*
 #define LIBTASN1_DEBUG
@@ -35,15 +47,9 @@
 
 #include <mem.h>
 
-#define MAX32 4294967295
-#define MAX24 16777215
-#define MAX16 65535
-
 #define MAX_LOG_SIZE 1024 /* maximum number of characters of a log message */
-#define MAX_NAME_SIZE 128 /* maximum number of characters of a name inside an ASN1 file definiton */
-#define MAX_ERROR_DESCRIPTION_SIZE 128 /* maximum number of characters of a description message */
 
-/* define used for visiting trees */
+/* Define used for visiting trees. */
 #define UP     1
 #define RIGHT  2
 #define DOWN   3
